Web3.py
=======

Web3.py is a python library for interacting with Ethereum.  Its API is derived
from the `Web3.js`_ Javascript API and should be familiar to anyone who has
used ``web3.js``.


Contents
--------

.. toctree::
    :maxdepth: 1

    quickstart
    overview
    node
    v4_migration
    filters
    contracts
    providers
    ens_overview
    middleware
    examples
    troubleshooting
    web3.main
    web3.eth
    web3.eth.account
    web3.pm
    web3.shh
    web3.personal
    web3.net
    web3.version
    web3.txpool
    web3.miner
    web3.admin
    gas_price
    ens
    internals
    conventions
    releases

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _Web3.js: https://github.com/ethereum/wiki/wiki/JavaScript-API
